@@ -152,6 +152,8 @@ sub format_select_lock
 
   $sql .= ' NOWAIT'  if($lock->{'nowait'});
 
+  $sql .= ' SKIP LOCKED'  if($lock->{'skip_locked'});
+
   return $sql;
 }
 
@@ -300,6 +302,10 @@ sub format_array
     {
       $_
     }
+    elsif(ref($_) eq 'ARRAY')
+    {
+      $self->format_array($_);
+    }
     else
     {
       s/\\/\\\\/g; 
